LineIndex

Struct LineIndex 

pub struct LineIndex { /* private fields */ }
Maps flat TextSize offsets to/from (line, column) representation.

Implementations

Source

impl LineIndex

pub fn new(text: &str) -> LineIndex

Returns a LineIndex for the text.

pub fn line_col(&self, offset: TextSize) -> LineCol

Transforms the TextSize into a LineCol.

Panics

If the offset is invalid. See Self::try_line_col.

pub fn try_line_col(&self, offset: TextSize) -> Option<LineCol>

Transforms the TextSize into a LineCol.

Returns None if the offset was invalid, e.g. if it extends past the end of the text or points to the middle of a multi-byte character.

pub fn offset(&self, line_col: LineCol) -> Option<TextSize>

Transforms the LineCol into a TextSize.

pub fn to_wide( &self, enc: WideEncoding, line_col: LineCol, ) -> Option<WideLineCol>

Transforms the LineCol with the given WideEncoding into a WideLineCol.

pub fn to_utf8( &self, enc: WideEncoding, line_col: WideLineCol, ) -> Option<LineCol>

Transforms the WideLineCol with the given WideEncoding into a LineCol.

pub fn line(&self, line: u32) -> Option<TextRange>

Returns the given line’s range.

pub fn lines(&self, range: TextRange) -> impl Iterator<Item = TextRange> + '_

Given a range [start, end), returns a sorted iterator of non-empty ranges [start, x1), [x1, x2), …, [xn, end) where all the xi, which are positions of newlines, are inside the range [start, end).

pub fn len(&self) -> TextSize

Returns the length of the original text.